# UI Services and Widgets

UI orchestration services and reusable widget containers.

---

## ThemeService

::: ezqt_app.services.ui.theme_service.ThemeService

---

## MenuService

::: ezqt_app.services.ui.menu_service.MenuService

---

## PanelService

::: ezqt_app.services.ui.panel_service.PanelService

---

## WindowService

::: ezqt_app.services.ui.window_service.WindowService

---

## UiComponentFactory

::: ezqt_app.services.ui.component_factory.UiComponentFactory

---

## Core Widgets

::: ezqt_app.widgets.core.ez_app.EzApplication

::: ezqt_app.widgets.core.header.Header

::: ezqt_app.widgets.core.menu.Menu

::: ezqt_app.widgets.core.page_container.PageContainer

::: ezqt_app.widgets.core.settings_panel.SettingsPanel

---

## Extended Widgets

::: ezqt_app.widgets.extended.setting_widgets
